@@ -53,7 +53,7 @@ void main_ui_enable(appdata_t *appdata) {
   char *str = NULL;
 #ifdef USE_HILDON
   if(project_valid) 
-    str = g_markup_printf_escaped("OSM2Go - <b>%s</b>", 
+    str = g_markup_printf_escaped("<b>%s</b> - OSM2Go", 
 				  appdata->project->name);
   else 
     str = g_markup_printf_escaped("OSM2Go");
@@ -61,7 +61,7 @@ void main_ui_enable(appdata_t *appdata) {
   hildon_window_set_markup(HILDON_WINDOW(appdata->window), str);
 #else
   if(project_valid) 
-    str = g_strdup_printf("OSM2Go - <b>%s</b>", appdata->project->name);
+    str = g_strdup_printf("%s - OSM2Go", appdata->project->name);
   else 
     str = g_strdup_printf("OSM2Go");
 
@@ -77,7 +77,8 @@ void main_ui_enable(appdata_t *appdata) {
   gtk_widget_set_sensitive(appdata->menu_item_map_upload, osm_valid);
   if(appdata->menu_item_map_undo)
     gtk_widget_set_sensitive(appdata->menu_item_map_undo, osm_valid);
-  gtk_widget_set_sensitive(appdata->menu_item_map_save_changes, osm_valid);
+  if(appdata->menu_item_map_save_changes)
+    gtk_widget_set_sensitive(appdata->menu_item_map_save_changes, osm_valid);
   gtk_widget_set_sensitive(appdata->menu_item_map_undo_changes, osm_valid);
   gtk_widget_set_sensitive(appdata->menu_item_map_relations, osm_valid);
   gtk_widget_set_sensitive(appdata->track.submenu_track, osm_valid);
@@ -269,7 +270,7 @@ cb_menu_undo_changes(GtkMenuItem *item, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
 
   if(!yes_no_f(GTK_WIDGET(appdata->window), NULL, 0, 0,
-	       _("Discard local changes?"), 
+	       _("Undo all changes?"), 
 	       _("Throw away all the changes you've not "
 		 "uploaded yet? This can't be undone.")))
     return;
@@ -282,7 +283,7 @@ cb_menu_undo_changes(GtkMenuItem *item, gpointer data) {
   map_paint(appdata);
   banner_busy_stop(appdata);  //"Redrawing"
 
-  banner_show_info(appdata, _("Discarded local changes"));
+  banner_show_info(appdata, _("Undo all changes"));
 }
 
 static void 
@@ -606,6 +607,8 @@ void menu_create(appdata_t *appdata) {
   /* -------------------- Project submenu -------------------- */
 
   GtkAccelGroup *accel_grp = gtk_accel_group_new();
+
+#ifndef USE_HILDON
   item = gtk_menu_item_new_with_mnemonic( _("_Project") );
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
   submenu = gtk_menu_new();
@@ -621,12 +624,17 @@ void menu_create(appdata_t *appdata) {
     0, 0, TRUE, FALSE, FALSE
   );
 
-#ifndef USE_HILDON
   menu_append_new_item(
     appdata, submenu, GTK_SIGNAL_FUNC(cb_menu_project_wizard), _("_Wizard"),
     GTK_STOCK_NEW, "<OSM2Go-Main>/Project/Wizard",
     0, 0, TRUE, FALSE, FALSE
   );
+#else
+  menu_append_new_item(
+    appdata, menu, GTK_SIGNAL_FUNC(cb_menu_project_open), _("_Project"),
+    GTK_STOCK_OPEN, "<OSM2Go-Main>/Project",
+    0, 0, TRUE, FALSE, FALSE
+  );
 #endif
 
   /* --------------- view menu ------------------- */
@@ -649,6 +657,7 @@ void menu_create(appdata_t *appdata) {
   );
 #endif
 
+#if !defined(ZOOM_BUTTONS) || !defined(USE_HILDON)
   menu_append_new_item(
     appdata, submenu, GTK_SIGNAL_FUNC(cb_menu_zoomin), _("Zoom _in"),
     GTK_STOCK_ZOOM_IN, "<OSM2Go-Main>/View/ZoomIn",
@@ -660,6 +669,7 @@ void menu_create(appdata_t *appdata) {
     GTK_STOCK_ZOOM_OUT, "<OSM2Go-Main>/View/ZoomOut",
     GDK_period, GDK_CONTROL_MASK, TRUE, FALSE, FALSE
   );
+#endif
 
   gtk_menu_shell_append(GTK_MENU_SHELL(submenu), gtk_separator_menu_item_new());
 
@@ -745,15 +755,17 @@ void menu_create(appdata_t *appdata) {
   } else
     printf("set environment variable OSM2GO_UNDO_TEST to enable undo framework tests\n");
 
+#ifndef USE_HILDON
   appdata->menu_item_map_save_changes = menu_append_new_item(
     appdata, submenu, GTK_SIGNAL_FUNC(cb_menu_save_changes), _("_Save local changes"),
     GTK_STOCK_SAVE, "<OSM2Go-Main>/Map/SaveChanges",
     GDK_s, GDK_SHIFT_MASK|GDK_CONTROL_MASK, TRUE, FALSE, FALSE
   );
+#endif
 
   appdata->menu_item_map_undo_changes = menu_append_new_item(
-    appdata, submenu, GTK_SIGNAL_FUNC(cb_menu_undo_changes), _("Disca_rd local changes"),
-    GTK_STOCK_DELETE, "<OSM2Go-Main>/Map/DiscardChanges",
+    appdata, submenu, GTK_SIGNAL_FUNC(cb_menu_undo_changes), _("Undo _all"),
+    GTK_STOCK_DELETE, "<OSM2Go-Main>/Map/UndoAll",
     0, 0, TRUE, FALSE, FALSE
   );
 
@@ -877,6 +889,9 @@ void menu_create(appdata_t *appdata) {
 
 #endif //USE_HILDON
 }
+
+void menu_cleanup(appdata_t *appdata) { }
+
 #else // !defined(USE_HILDON) || (MAEMO_VERSION_MAJOR < 5)
 
 void submenu_entry(appdata_t *appdata, HildonAppMenu *menu,
@@ -893,6 +908,12 @@ typedef struct {
   GtkSignalFunc activate_cb;
 } menu_entry_t;
 
+typedef struct {
+  const char *title;
+  const menu_entry_t *menu;
+  int len;
+} submenu_t;
+
 static gboolean no_icon_get_toggle(appdata_t *appdata) {
   if(!appdata)           return FALSE;
   if(!appdata->settings) return FALSE;
@@ -937,6 +958,9 @@ static GtkWidget *app_menu_create(appdata_t *appdata,
 			     menu_entries->activate_cb, appdata); 
     }
 
+    hildon_button_set_title_alignment(HILDON_BUTTON(button), 0.5, 0.5);
+    hildon_button_set_value_alignment(HILDON_BUTTON(button), 0.5, 0.5);
+
     /* offset to GtkWidget pointer was given -> store pointer */
     if(menu_entries->offset) 
       *(GtkWidget**)(((void*)appdata)+menu_entries->offset) = button;
@@ -951,25 +975,149 @@ static GtkWidget *app_menu_create(appdata_t *appdata,
   return GTK_WIDGET(menu);
 }
 
+#ifdef MAEMO5_SUBMENU_POPUP
+static GtkWidget *app_submenu_create(appdata_t *appdata, 
+				     const submenu_t *submenu) {
+  return app_menu_create(appdata, submenu->menu);
+}
+
+static void submenu_popup(GtkWidget *menu) {
+  GtkWidget *top = hildon_window_stack_peek(hildon_window_stack_get_default());
+
+#if 0 // nasty workaround for race condition in hildonappmenu
+  int start, end;
+  GTimeVal tv;
+  g_get_current_time(&tv);
+  start = tv.tv_sec * 1000 + tv.tv_usec / 1000; 
+  do {
+    if(gtk_events_pending()) 
+      while(gtk_events_pending()) {
+	putchar('.'); fflush(stdout);
+	gtk_main_iteration();
+      }
+    else
+      usleep(100);
+
+    g_get_current_time(&tv);
+    end = tv.tv_sec * 1000 + tv.tv_usec / 1000; 
+  } while(end-start < 500);
+#endif
+
+  hildon_app_menu_popup(HILDON_APP_MENU(menu), GTK_WINDOW(top));
+}
+
+static void submenu_cleanup(GtkWidget *menu) {
+  g_object_unref(menu);
+}
+#else
+#define COLUMNS  2
+
+void on_submenu_entry_clicked(GtkButton *button, GtkWidget *menu) {
+
+  /* force closing of submenu dialog */
+  gtk_dialog_response(GTK_DIALOG(menu), GTK_RESPONSE_NONE);
+  gtk_widget_hide(menu);
+  
+  /* let gtk clean up */
+  while(gtk_events_pending()) 
+    gtk_main_iteration();
+}
+
+/* use standard dialog boxes for fremantle submenues */
+static GtkWidget *app_submenu_create(appdata_t *appdata, 
+				     const submenu_t *submenu) {
+
+  /* create a oridinary dialog box */
+  GtkWidget *dialog = misc_dialog_new(MISC_DIALOG_SMALL, _(submenu->title),
+				      GTK_WINDOW(appdata->window), NULL);
+
+  gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
+
+  GtkWidget *table = gtk_table_new(submenu->len/COLUMNS, COLUMNS, TRUE);
+  int x = 0, y = 0;
+
+  const menu_entry_t *menu_entries = submenu->menu;
+  while(menu_entries->label) {
+    GtkWidget *button = NULL;
+
+    if(!menu_entries->toggle) {
+      button = hildon_button_new_with_text(
+	    HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
+	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+	    _(menu_entries->label), _(menu_entries->value));
+
+      g_signal_connect(button, "clicked", 
+		       G_CALLBACK(on_submenu_entry_clicked), dialog); 
+
+      g_signal_connect(button, "clicked", 
+		       menu_entries->activate_cb, appdata); 
+      
+      hildon_button_set_title_alignment(HILDON_BUTTON(button), 0.5, 0.5);
+      hildon_button_set_value_alignment(HILDON_BUTTON(button), 0.5, 0.5);
+    } else {
+      button = hildon_check_button_new(HILDON_SIZE_AUTO);
+      gtk_button_set_label(GTK_BUTTON(button), _(menu_entries->label));
+      printf("requesting check for %s: %p\n", menu_entries->label,
+	     menu_entries->toggle);
+      hildon_check_button_set_active(HILDON_CHECK_BUTTON(button), 
+				     menu_entries->toggle(appdata));
+
+      g_signal_connect(button, "clicked", 
+		       G_CALLBACK(on_submenu_entry_clicked), dialog); 
+
+      g_signal_connect(button, "toggled", 
+		       menu_entries->activate_cb, appdata); 
+
+      gtk_button_set_alignment(GTK_BUTTON(button), 0.5, 0.5);
+    }
+
+    /* offset to GtkWidget pointer was given -> store pointer */
+    if(menu_entries->offset) 
+      *(GtkWidget**)(((void*)appdata)+menu_entries->offset) = button;
+
+    gtk_widget_set_sensitive(button, menu_entries->enabled);
+
+    gtk_table_attach_defaults(GTK_TABLE(table),  button, x, x+1, y, y+1);
+    
+    x++;
+    if(x == COLUMNS) { x = 0; y++; }
+
+    menu_entries++;
+  }
+
+
+  gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), table);
+
+  return dialog;
+}
+
+/* popup the dialog shaped submenu */
+static void submenu_popup(GtkWidget *menu) {
+  gtk_widget_show_all(menu);
+  gtk_dialog_run(GTK_DIALOG(menu));
+  gtk_widget_hide(menu);
+}
+
+static void submenu_cleanup(GtkWidget *menu) {
+  gtk_widget_destroy(menu);
+}
+#endif
+
 /* the view submenu */
 void on_submenu_view_clicked(GtkButton *button, appdata_t *appdata) {
-  hildon_app_menu_popup(HILDON_APP_MENU(appdata->app_menu_view), 
-			GTK_WINDOW(appdata->window));
+  submenu_popup(appdata->app_menu_view);
 }
 
 void on_submenu_map_clicked(GtkButton *button, appdata_t *appdata) {
-  hildon_app_menu_popup(HILDON_APP_MENU(appdata->app_menu_map), 
-			GTK_WINDOW(appdata->window));
+  submenu_popup(appdata->app_menu_map);
 }
 
 void on_submenu_wms_clicked(GtkButton *button, appdata_t *appdata) {
-  hildon_app_menu_popup(HILDON_APP_MENU(appdata->app_menu_wms), 
-			GTK_WINDOW(appdata->window));
+  submenu_popup(appdata->app_menu_wms);
 }
 
 void on_submenu_track_clicked(GtkButton *button, appdata_t *appdata) {
-  hildon_app_menu_popup(HILDON_APP_MENU(appdata->app_menu_track), 
-			GTK_WINDOW(appdata->window));
+  submenu_popup(appdata->app_menu_track);
 }
 
 #define APP_OFFSET(a)  offsetof(appdata_t, a)
@@ -984,9 +1132,11 @@ void on_submenu_track_clicked(GtkButton *button, appdata_t *appdata) {
 #define LAST_ENTRY            { NULL, NULL, FALSE, NULL, 0, NULL }
 
 /* -- the view submenu -- */
-static const menu_entry_t submenu_view[] = {
+static const menu_entry_t submenu_view_entries[] = {
+#ifndef ZOOM_BUTTONS
   SIMPLE_ENTRY("Zoom in",         cb_menu_zoomin),
   SIMPLE_ENTRY("Zoom out",        cb_menu_zoomout),
+#endif
   /* --- */
   SIMPLE_ENTRY("Style",           cb_menu_style),
   /* --- */
@@ -1002,22 +1152,32 @@ static const menu_entry_t submenu_view[] = {
   LAST_ENTRY
 };
 
+static const submenu_t submenu_view = {
+  "View", submenu_view_entries, 
+  sizeof(submenu_view_entries)/sizeof(menu_entry_t)-1
+};
+
 /* -- the map submenu -- */
-static const menu_entry_t submenu_map[] = {
+static const menu_entry_t submenu_map_entries[] = {
   ENABLED_ENTRY("Upload",                cb_menu_upload, menu_item_map_upload),
   SIMPLE_ENTRY("Download",               cb_menu_download),
-  ENABLED_ENTRY("Save local changes",    cb_menu_save_changes, 
-		                           menu_item_map_save_changes),
-  ENABLED_ENTRY("Discard local changes", cb_menu_undo_changes, 
-		                           menu_item_map_undo_changes),
+  //  ENABLED_ENTRY("Save changes",          cb_menu_save_changes, 
+  //		menu_item_map_save_changes),
+  ENABLED_ENTRY("Undo all",              cb_menu_undo_changes, 
+		menu_item_map_undo_changes),
   ENABLED_ENTRY("Relations",             cb_menu_osm_relations, 
-		                           menu_item_map_relations),
+		menu_item_map_relations),
 
   LAST_ENTRY
 };
 
+static const submenu_t submenu_map = {
+  "Map", submenu_map_entries, 
+  sizeof(submenu_map_entries)/sizeof(menu_entry_t)-1
+};
+
 /* -- the wms submenu -- */
-static const menu_entry_t submenu_wms[] = {
+static const menu_entry_t submenu_wms_entries[] = {
   SIMPLE_ENTRY("Import",   cb_menu_wms_import),
   DISABLED_ENTRY("Clear",  cb_menu_wms_clear, menu_item_wms_clear),
   DISABLED_ENTRY("Adjust", cb_menu_wms_adjust, menu_item_wms_adjust),
@@ -1025,8 +1185,13 @@ static const menu_entry_t submenu_wms[] = {
   LAST_ENTRY
 };
 
+static const submenu_t submenu_wms = {
+  "WMS", submenu_wms_entries, 
+  sizeof(submenu_wms_entries)/sizeof(menu_entry_t)-1
+};
+
 /* -- the track submenu -- */
-static const menu_entry_t submenu_track[] = {
+static const menu_entry_t submenu_track_entries[] = {
   ENABLED_ENTRY("Import",  cb_menu_track_import, track.menu_item_track_import),
   DISABLED_ENTRY("Export", cb_menu_track_export, track.menu_item_track_export),
   DISABLED_ENTRY("Clear",  cb_menu_track_clear, track.menu_item_track_clear),
@@ -1038,6 +1203,11 @@ static const menu_entry_t submenu_track[] = {
   LAST_ENTRY
 };
 
+static const submenu_t submenu_track = {
+  "Track", submenu_track_entries, 
+  sizeof(submenu_track_entries)/sizeof(menu_entry_t)-1
+};
+
 
 /* -- the applications main menu -- */
 static const menu_entry_t main_menu[] = {
@@ -1056,10 +1226,14 @@ void menu_create(appdata_t *appdata) {
  
   /* build menu/submenus */
   menu = HILDON_APP_MENU(app_menu_create(appdata, main_menu));
-  appdata->app_menu_wms   = app_menu_create(appdata, submenu_wms);
-  appdata->app_menu_map   = app_menu_create(appdata, submenu_map);
-  appdata->app_menu_view  = app_menu_create(appdata, submenu_view);
-  appdata->app_menu_track = app_menu_create(appdata, submenu_track);
+  appdata->app_menu_wms   = app_submenu_create(appdata, &submenu_wms);
+  g_object_ref(appdata->app_menu_wms);
+  appdata->app_menu_map   = app_submenu_create(appdata, &submenu_map);
+  g_object_ref(appdata->app_menu_map);
+  appdata->app_menu_view  = app_submenu_create(appdata, &submenu_view);
+  g_object_ref(appdata->app_menu_view);
+  appdata->app_menu_track = app_submenu_create(appdata, &submenu_track);
+  g_object_ref(appdata->app_menu_track);
 
   /* enable/disable some entries according to settings */
   if(appdata && appdata->settings)
@@ -1068,6 +1242,13 @@ void menu_create(appdata_t *appdata) {
 
   hildon_window_set_app_menu(HILDON_WINDOW(appdata->window), menu);
 }
+
+void menu_cleanup(appdata_t *appdata) { 
+  submenu_cleanup(appdata->app_menu_view);
+  submenu_cleanup(appdata->app_menu_map);
+  submenu_cleanup(appdata->app_menu_wms);
+  submenu_cleanup(appdata->app_menu_track);
+}
 #endif
 
 /********************* end of menu **********************/
@@ -1141,7 +1322,9 @@ void cleanup(appdata_t *appdata) {
   project_free(appdata->project);
 
   if(appdata->menu_item_map_undo)
-    undo_free(appdata->undo.state);
+    undo_free(appdata->osm, appdata->undo.state);
+
+  menu_cleanup(appdata);
 
   puts("everything is gone");
 }
@@ -1193,6 +1376,57 @@ gboolean on_window_key_press(GtkWidget *widget,
   return handled;
 }
 
+#ifdef DETAIL_POPUP
+#define HEIGHT 100
+
+static void detail_level_popup(GtkWidget *button, appdata_t *appdata) {
+  GtkWidget *overlay = gtk_window_new(GTK_WINDOW_POPUP);
+  gtk_window_set_default_size(GTK_WINDOW(overlay), button->allocation.width, HEIGHT); 
+  gtk_widget_realize(overlay);
+
+  //  gtk_window_set_resizable(GTK_WINDOW(overlay), FALSE);
+
+  gtk_window_set_transient_for(GTK_WINDOW(overlay), GTK_WINDOW(appdata->window));
+  gtk_window_set_keep_above(GTK_WINDOW(overlay), TRUE);    
+  gtk_window_set_destroy_with_parent(GTK_WINDOW(overlay), TRUE);
+  gtk_window_set_gravity(GTK_WINDOW(overlay), GDK_GRAVITY_STATIC);
+  gtk_window_set_modal(GTK_WINDOW(overlay), TRUE);
+
+  gdk_pointer_grab(overlay->window, TRUE,
+		   GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_MOTION_MASK,
+		   NULL, NULL, GDK_CURRENT_TIME);
+  gtk_grab_add(overlay->window);
+
+#if 0
+  gtk_window_set_position(GTK_WINDOW(overlay), GTK_WIN_POS_MOUSE);
+#else
+  gint x, y;
+  GdkWindow *wpar = gtk_widget_get_parent_window(button);
+  gdk_window_get_root_origin(wpar, &x, &y);
+  gtk_window_move(GTK_WINDOW(overlay), 
+		  x + button->allocation.x, 
+		  y + button->allocation.y - HEIGHT);
+#endif
+
+  /* a frame with a vscale inside */
+  GtkWidget *frame = gtk_frame_new(NULL);
+  gtk_widget_show (frame);
+  gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_OUT);
+  GtkObject *adjustment = gtk_adjustment_new(1.0, 0.1, 10.0, +1, -1, 1);
+  GtkWidget *scale = gtk_vscale_new(GTK_ADJUSTMENT(adjustment));
+  gtk_container_add(GTK_CONTAINER(frame), scale);
+  gtk_container_add(GTK_CONTAINER(overlay), frame);
+  
+  gtk_widget_show_all(overlay);
+
+  /* handle this popup until it's gone */
+  
+
+
+
+}
+#endif
+
 int main(int argc, char *argv[]) {
   appdata_t appdata;
 
@@ -1238,8 +1472,8 @@ int main(int argc, char *argv[]) {
 #endif
   hildon_program_add_window(appdata.program, appdata.window);
 
-#if MAEMO_VERSION_MAJOR == 6
-  unsigned long val;
+#if MAEMO_VERSION_MAJOR == 5
+  unsigned long val = True;
   XChangeProperty(GDK_DISPLAY(),
 		  GDK_WINDOW_XID(GTK_WIDGET(appdata.window)->window),
 		  XInternAtom(GDK_DISPLAY(),
@@ -1292,11 +1526,24 @@ int main(int argc, char *argv[]) {
 
   gtk_box_pack_start(GTK_BOX(vbox), map, TRUE, TRUE, 0);
 
-#ifdef ZOOM_BUTTONS  
+#if defined(ZOOM_BUTTONS) || defined(DETAIL_POPUP)
   GtkWidget *zhbox = gtk_hbox_new(FALSE, 0);
 
   gtk_box_pack_start_defaults(GTK_BOX(zhbox), statusbar_new(&appdata));
+#endif
 
+#ifdef DETAIL_POPUP
+  /* ---- detail popup ---- */
+  appdata.btn_detail_popup = gtk_button_new();
+  gtk_button_set_image(GTK_BUTTON(appdata.btn_detail_popup), 
+	gtk_image_new_from_stock(GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU));
+  g_signal_connect(appdata.btn_detail_popup, "clicked", 
+		   G_CALLBACK(detail_level_popup), &appdata);
+  gtk_box_pack_start(GTK_BOX(zhbox), appdata.btn_detail_popup, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), zhbox, FALSE, FALSE, 0);
+#endif
+
+#ifdef ZOOM_BUTTONS
   /* ---- add zoom out button right of statusbar ---- */
   appdata.btn_zoom_out = gtk_button_new();
   gtk_button_set_image(GTK_BUTTON(appdata.btn_zoom_out), 
@@ -1312,8 +1559,9 @@ int main(int argc, char *argv[]) {
   g_signal_connect(appdata.btn_zoom_in, "clicked", 
 		   G_CALLBACK(cb_menu_zoomin), &appdata);
   gtk_box_pack_start(GTK_BOX(zhbox), appdata.btn_zoom_in, FALSE, FALSE, 0);
+#endif
 
-
+#if defined(ZOOM_BUTTONS) || defined(DETAIL_POPUP)
   gtk_box_pack_start(GTK_BOX(vbox), zhbox, FALSE, FALSE, 0);
 #else
   gtk_box_pack_start(GTK_BOX(vbox), statusbar_new(&appdata), FALSE, FALSE, 0);
@@ -1351,33 +1599,6 @@ int main(int argc, char *argv[]) {
   while(gtk_events_pending()) 
     gtk_main_iteration();
 
-#if 0  // test overlay
-  {
-    GtkWidget *overlay = gtk_window_new(GTK_WINDOW_POPUP);
-    gtk_window_set_default_size(GTK_WINDOW(overlay), 40, 20);
-    gtk_window_set_transient_for(GTK_WINDOW(overlay), GTK_WINDOW(appdata.window));
-    gtk_window_set_keep_above(GTK_WINDOW(overlay), TRUE);    
-    gtk_window_set_destroy_with_parent(GTK_WINDOW(overlay), TRUE);
-    gtk_window_set_position(GTK_WINDOW(overlay), GTK_WIN_POS_CENTER_ON_PARENT);
-
-    gtk_window_set_gravity(GTK_WINDOW(overlay), GDK_GRAVITY_NORTH_EAST);
-
-    printf("x = %d\n", gdk_screen_width() - overlay->allocation.width);
-    gtk_window_move(GTK_WINDOW(overlay), 
-		    gdk_screen_width() - overlay->allocation.width, 60);
-
-    gtk_window_set_decorated(GTK_WINDOW(overlay), TRUE);
-
-    /* add some zoom buttons for testing */
-    GtkWidget *hbox = gtk_hbox_new(TRUE, 0);
-    gtk_box_pack_start_defaults(GTK_BOX(hbox), gtk_button_new_with_label("+"));
-    gtk_box_pack_start_defaults(GTK_BOX(hbox), gtk_button_new_with_label("-"));
-    gtk_container_add(GTK_CONTAINER(overlay), hbox);
-
-    gtk_widget_show_all(overlay);
-  }
-#endif
-
   /* start to interact with the user now that the gui is running */
   if(appdata.settings->first_run_demo) {
     messagef(GTK_WIDGET(appdata.window), _("Welcome to OSM2Go"),
