@@ -25,33 +25,8 @@
 #undef DESTROY_WAIT_FOR_GTK
 
 static void map_statusbar(map_t *map, map_item_t *map_item) {
-  char *item_str = NULL;
-  item_id_t id = ID_ILLEGAL;
-  tag_t *tag = NULL;
+  tag_t *tag = OBJECT_TAG(map_item->object);
   char *str = NULL;
-  
-  switch(map_item->object.type) {
-  case NODE:
-    item_str = "Node";
-    id = map_item->object.node->id;
-    tag = map_item->object.node->tag;
-    break;
-
-  case WAY:
-    item_str = "Way";
-    id = map_item->object.way->id;
-    tag = map_item->object.way->tag;
-    break;
-
-  case RELATION:
-    item_str = "Relation";
-    id = map_item->object.relation->id;
-    tag = map_item->object.relation->tag;
-    break;
-
-  default:
-    break;
-  }
 
   gboolean collision = FALSE;
   tag_t *tags = tag;
@@ -61,7 +36,7 @@ static void map_statusbar(map_t *map, map_item_t *map_item) {
     tag = tag->next;
   }
 
-  str = osm_object_get_speaking_name(&map_item->object);
+  str = osm_object_get_name(&map_item->object);
   statusbar_set(map->appdata, str, collision);
   g_free(str);
 }
@@ -278,7 +253,7 @@ void map_way_select(appdata_t *appdata, way_t *way) {
 void map_relation_select(appdata_t *appdata, relation_t *relation) {
   map_t *map = appdata->map;
 
-  printf("highlighting relation "ITEM_ID_FORMAT"\n", relation->id);
+  printf("highlighting relation "ITEM_ID_FORMAT"\n", OSM_ID(relation));
 
   g_assert(!map->highlight);
   map_highlight_t **hl = &map->highlight;
@@ -301,7 +276,7 @@ void map_relation_select(appdata_t *appdata, relation_t *relation) {
 
     case NODE: {
       node_t *node = member->object.node;
-      printf("  -> node "ITEM_ID_FORMAT"\n", node->id);
+      printf("  -> node "ITEM_ID_FORMAT"\n", OSM_ID(node));
 
       item = canvas_circle_new(map->canvas, CANVAS_GROUP_NODES_HL, 
 			node->lpos.x, node->lpos.y, 
@@ -379,13 +354,13 @@ void map_item_deselect(appdata_t *appdata) {
       osm_tags_free(appdata->map->last_node_tags);
 
     appdata->map->last_node_tags = 
-      osm_tags_copy(appdata->map->selected.object.node->tag, FALSE);
+      osm_tags_copy(OBJECT_TAG(appdata->map->selected.object));
   } else if(appdata->map->selected.object.type == WAY) {
     if(appdata->map->last_way_tags) 
       osm_tags_free(appdata->map->last_way_tags);
 
     appdata->map->last_way_tags = 
-      osm_tags_copy(appdata->map->selected.object.way->tag, FALSE);
+      osm_tags_copy(OBJECT_TAG(appdata->map->selected.object));
   }
 
   /* remove statusbar message */
@@ -551,7 +526,7 @@ void map_show_node(map_t *map, node_t *node) {
 void map_way_draw(map_t *map, way_t *way) {
 
   /* don't draw a way that's not there anymore */
-  if(way->flags & (OSM_FLAG_DELETED | OSM_FLAG_HIDDEN))
+  if(OSM_FLAGS(way) & (OSM_FLAG_DELETED | OSM_FLAG_HIDDEN))
     return;
 
   /* allocate space for nodes */
@@ -597,7 +572,7 @@ void map_way_draw(map_t *map, way_t *way) {
 
 void map_node_draw(map_t *map, node_t *node) {
   /* don't draw a node that's not there anymore */
-  if(node->flags & OSM_FLAG_DELETED)
+  if(OSM_FLAGS(node) & OSM_FLAG_DELETED)
     return;
 
   if(!node->ways) 
@@ -870,17 +845,9 @@ map_item_t *map_item_at(map_t *map, gint x, gint y) {
   if(map_item->highlight) 
     printf("  item is highlight\n");    
 
-  switch(map_item->object.type) {
-  case NODE:
-    printf("  item is node #"ITEM_ID_FORMAT"\n", map_item->object.node->id);
-    break;
-  case WAY:
-    printf("  item is way #"ITEM_ID_FORMAT"\n", map_item->object.way->id);
-    break;
-  default:
-    printf("  unknown item\n");
-    break;
-  }
+  printf("  item is %s #"ITEM_ID_FORMAT"\n", 
+	 osm_object_type_string(&map_item->object),
+	 OBJECT_ID(map_item->object));
 
   return map_item;
 }    
@@ -902,7 +869,7 @@ map_item_t *map_real_item_at(map_t *map, gint x, gint y) {
 
     if(parent)
       printf("  using parent item node #" ITEM_ID_FORMAT "\n", 
-	     parent->object.node->id);      
+	     OBJECT_ID(parent->object));      
     break;
 
   case WAY:
@@ -911,7 +878,7 @@ map_item_t *map_real_item_at(map_t *map, gint x, gint y) {
 
     if(parent)
       printf("  using parent item way #" ITEM_ID_FORMAT "\n", 
-	     parent->object.way->id);      
+	     OBJECT_ID(parent->object));      
     break;
 
   default:
@@ -942,8 +909,8 @@ static void map_limit_scroll(map_t *map, canvas_unit_t unit,
   gdouble sy_cu = *sy / scale;
   
   /* get size of visible area in canvas units (meters) */
-  gint aw_cu = canvas_get_viewport_width(map->canvas, CANVAS_UNIT_METER);
-  gint ah_cu = canvas_get_viewport_height(map->canvas, CANVAS_UNIT_METER);
+  gint aw_cu = canvas_get_viewport_width(map->canvas, CANVAS_UNIT_METER)/2;
+  gint ah_cu = canvas_get_viewport_height(map->canvas, CANVAS_UNIT_METER)/2;
   
   // Data rect minimum and maximum
   gint min_x, min_y, max_x, max_y;
@@ -955,8 +922,8 @@ static void map_limit_scroll(map_t *map, canvas_unit_t unit,
   // limit stops - prevent scrolling beyond these
   gint min_sy_cu = 0.95*(min_y - ah_cu);
   gint min_sx_cu = 0.95*(min_x - aw_cu);
-  gint max_sy_cu = 0.95*(max_y);
-  gint max_sx_cu = 0.95*(max_x);
+  gint max_sy_cu = 0.95*(max_y + ah_cu);
+  gint max_sx_cu = 0.95*(max_x + aw_cu);
   if (sy_cu < min_sy_cu) { *sy = min_sy_cu * scale; }
   if (sx_cu < min_sx_cu) { *sx = min_sx_cu * scale; }
   if (sy_cu > max_sy_cu) { *sy = max_sy_cu * scale; }
@@ -1006,12 +973,14 @@ static gboolean map_limit_zoom(map_t *map, gdouble *zoom) {
 
 /*
  * Scroll the map to a point if that point is currently offscreen.
+ * Return true if this was possible, false if position is outside
+ * working area
  */
-void map_scroll_to_if_offscreen(map_t *map, lpos_t *lpos) {
+gboolean map_scroll_to_if_offscreen(map_t *map, lpos_t *lpos) {
 
   // Ignore anything outside the working area
   if (!(map && map->appdata && map->appdata->osm)) {
-    return;
+    return FALSE;
   }
   gint min_x, min_y, max_x, max_y;
   min_x = map->appdata->osm->bounds->min.x;
@@ -1022,7 +991,7 @@ void map_scroll_to_if_offscreen(map_t *map, lpos_t *lpos) {
       || (lpos->y > max_y) || (lpos->y < min_y)) {
     printf("cannot scroll to (%d, %d): outside the working area\n",
 	   lpos->x, lpos->y);
-    return;
+    return FALSE;
   }
 
   // Viewport dimensions in canvas space
@@ -1062,12 +1031,13 @@ void map_scroll_to_if_offscreen(map_t *map, lpos_t *lpos) {
     gint new_sx, new_sy;
 
     // Just centre both at once
-    new_sx = pix_per_meter * (lpos->x - (aw/2));
-    new_sy = pix_per_meter * (lpos->y - (ah/2));
+    new_sx = pix_per_meter * lpos->x; // XXX (lpos->x - (aw/2));
+    new_sy = pix_per_meter * lpos->y; // XXX (lpos->y - (ah/2));
 
     map_limit_scroll(map, CANVAS_UNIT_PIXEL, &new_sx, &new_sy);
     canvas_scroll_to(map->canvas, CANVAS_UNIT_PIXEL, new_sx, new_sy);
   }
+  return TRUE;
 }
 
 /* Deselects the current way or node if its zoom_max
@@ -1278,7 +1248,9 @@ void map_highlight_refresh(appdata_t *appdata) {
 }
 
 void map_way_delete(appdata_t *appdata, way_t *way) {
-  printf("deleting way #" ITEM_ID_FORMAT " from map and osm\n", way->id);
+  printf("deleting way #" ITEM_ID_FORMAT " from map and osm\n", OSM_ID(way));
+
+  undo_append_way(appdata, UNDO_DELETE, way);
 
   /* remove it visually from the screen */
   map_item_chain_destroy(&way->map_item_chain);
@@ -1294,6 +1266,7 @@ void map_way_delete(appdata_t *appdata, way_t *way) {
 
   /* and mark it "deleted" in the database */
   osm_way_remove_from_relation(appdata->osm, way);
+
   osm_way_delete(appdata->osm, &appdata->icon, way, FALSE);
 }
 
@@ -1355,7 +1328,7 @@ static void map_touchnode_update(appdata_t *appdata, gint x, gint y) {
   while(!map->touchnode && node) {
     /* don't highlight the dragged node itself and don't highlight */
     /* deleted ones */
-    if((node != cur_node) && (!(node->flags & OSM_FLAG_DELETED))) {
+    if((node != cur_node) && (!(OSM_FLAGS(node) & OSM_FLAG_DELETED))) {
       gint nx = abs(x - node->lpos.x);
       gint ny = abs(y - node->lpos.y);
 
@@ -1973,12 +1946,14 @@ void map_delete_selected(appdata_t *appdata) {
   /* deleting the selected item de-selects it ... */
   map_item_deselect(appdata);
 
-  undo_remember_delete(appdata, &item.object);
+  undo_open_new_state(appdata, UNDO_DELETE, &item.object);
 
   switch(item.object.type) {
   case NODE:
     printf("request to delete node #" ITEM_ID_FORMAT "\n", 
-	   item.object.node->id);
+	   OBJECT_ID(item.object));
+
+    undo_append_object(appdata, UNDO_DELETE, &item.object);
 
     /* check if this node is part of a way with two nodes only. */
     /* we cannot delete this as this would also delete the way */
@@ -2028,6 +2003,7 @@ void map_delete_selected(appdata_t *appdata) {
 	map_item_t item;
 	item.object.type = WAY;
 	item.object.way = chain->way;
+	undo_append_object(appdata, UNDO_MODIFY, &(item.object));
 	map_item_redraw(appdata, &item);
       }
 
@@ -2039,7 +2015,8 @@ void map_delete_selected(appdata_t *appdata) {
     break;
 
   case WAY:
-    printf("request to delete way #" ITEM_ID_FORMAT "\n", item.object.way->id);
+    printf("request to delete way #" ITEM_ID_FORMAT "\n", 
+	   OBJECT_ID(item.object));
     map_way_delete(appdata, item.object.way);
     break;
 
@@ -2048,6 +2025,7 @@ void map_delete_selected(appdata_t *appdata) {
 	     (item.object.type == WAY));
     break;
   }
+  undo_close_state(appdata);
 }
 
 /* ----------------------- track related stuff ----------------------- */
@@ -2350,10 +2328,10 @@ void map_hide_selected(appdata_t *appdata) {
   }
 
   way_t *way = map->selected.object.way;
-  printf("hiding way #" ITEM_ID_FORMAT "\n", way->id);
+  printf("hiding way #" ITEM_ID_FORMAT "\n", OSM_ID(way));
 
   map_item_deselect(appdata);
-  way->flags |= OSM_FLAG_HIDDEN;
+  OSM_FLAGS(way) |= OSM_FLAG_HIDDEN;
   map_item_chain_destroy(&way->map_item_chain);
 
   gtk_widget_set_sensitive(appdata->menu_item_map_show_all, TRUE);
@@ -2365,8 +2343,8 @@ void map_show_all(appdata_t *appdata) {
 
   way_t *way = appdata->osm->way;
   while(way) {
-    if(way->flags & OSM_FLAG_HIDDEN) {
-      way->flags &= ~OSM_FLAG_HIDDEN;
+    if(OSM_FLAGS(way) & OSM_FLAG_HIDDEN) {
+      OSM_FLAGS(way) &= ~OSM_FLAG_HIDDEN;
       map_way_draw(map, way);
     }
 
